"""
Application to manage notifications.

.. note::
  This application allow to create notification emails

.. image:: _images/models.png
   :width: 100%
   :align: center

:copyright: (c) 2022 by François GUÉRIN
:license: mit, see LICENSE for more details.
:creationdate: 06/01/2022 11:31
:moduleauthor: François GUÉRIN <fguerin@ville-tourcoing.fr>
:modulename: django_notifications

"""

from .__about__ import __version__

VERSION = __version__


__all__ = [
    "__version__",
    "VERSION",
]



# Generated by Django 4.2.16 on 2024-10-15 06:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_notifications', '0005_debugging'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='as_bcc',
            field=models.BooleanField(default=False, help_text='Email message will be sent as BCC values.', verbose_name='As bcc'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='delayed_sending_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Envoi retardé le'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='from_email',
            field=models.EmailField(default='documentation@ville-tourcoing.fr', help_text='Adresse électronique à utiliser comme expéditeur', max_length=254, verbose_name='Expéditeur'),
        ),
        migrations.AlterField(
            model_name='notificationconfig',
            name='debug_notifications_email',
            field=models.EmailField(blank=True, default='', help_text="Adresse électronique d'envoi des copies des notifications.", max_length=254, verbose_name='Adresse électronique de débogage des notifications'),
        ),
        migrations.AlterField(
            model_name='notificationconfig',
            name='delay',
            field=models.PositiveIntegerField(default=0, help_text='Délais en secondes.', verbose_name='Délais'),
        ),
        migrations.AlterField(
            model_name='notificationconfig',
            name='enable_debug_notifications',
            field=models.BooleanField(default=False, help_text="Si activé, une copie des notifications sera envoyé à l'adresse électronique fournie.", verbose_name='Activer les débogage des notifications'),
        ),
    ]



"""
forms for :mod:`django_notifications.admin` application.

:creationdate:  07/01/2022 10:33
:moduleauthor: François GUÉRIN <fguerin@ville-tourcoing.fr>
:modulename: django_notifications.admin.forms
"""

import logging

from django import forms

from django_notifications import models

__author__ = "fguerin"
logger = logging.getLogger(__name__)


class NotificationAdminForm(forms.ModelForm):
    """Admin form for :class:`django_notifications.models.Notification` model."""

    class Meta:
        """Metaclass for :class:`django_notifications.admin.NotificationAdminForm`."""

        model = models.Notification
        fields = (
            "delayed_sending_at",
            "subject",
            "text_body",
            "html_body",
            "content_type",
            "object_id",
            "state_from",
            "state_to",
            "recipients",
            "email_recipients",
            "from_email",
        )



"""Conf for django-notifications sphinx docs."""
# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

import sphinx_rtd_theme

sys.path.insert(0, os.path.abspath("../.."))

# -- Project information -----------------------------------------------------

project = "django-notifications"
copyright = "2022, François GUÉRIN <fguerin@ville-tourcoing.fr>"  # noqa: A001
author = "François GUÉRIN <fguerin@ville-tourcoing.fr>"

# The full version, including alpha/beta/rc tags
version = "0.12"
release = "0.12.1"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.intersphinx",
    "sphinx.ext.todo",
    "sphinx.ext.imgmath",
    "sphinx.ext.viewcode",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = [
    "**/migrations*",
    "**/fixtures*",
    "**/locale*",
    "**/tests*",
]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"
html_theme_path = [
    sphinx_rtd_theme.get_html_theme_path(),
]

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

intersphinx_mapping = {
    "python": ("https://docs.python.org/", None),
    "django": (
        "http://docs.djangoproject.com/en/3.2/",
        "https://docs.djangoproject.com/en/3.2/_objects/",
    ),
}



# Generated by Django 5.2 on 2025-04-11 09:58

import django.db.models.deletion
import django_notifications.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_notifications', '0006_notification_as_bcc_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='attachment_file',
            field=models.FileField(upload_to='notifications/attachments/%Y/%m/%d/', verbose_name='Pièce jointe'),
        ),
        migrations.AlterField(
            model_name='attachment',
            name='notification',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='attachments', to='django_notifications.notification', verbose_name='Notification'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='as_bcc',
            field=models.BooleanField(default=False, help_text='Les adresses électronique vont être utilisées dans le champs BCC (copies cachées).', verbose_name='Comme BCC'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='from_email',
            field=models.EmailField(default=django_notifications.models.default_from_email, help_text='Adresse électronique à utiliser comme expéditeur', max_length=254, verbose_name='Expéditeur'),
        ),
    ]
